@@ -450,6 +450,16 @@ def create_inf_dep(
     category="Auto-scaling options",
     show_default=True,
 )
+@click.option(
+    "--autoscaling_strategy",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.Choice(["rps_per_worker", "ttft_latency_sec"]),
+    required=False,
+    default=DEFAULT_AUTOSCALING_CONFIG.autoscaling_strategy,
+    help="Autoscaling strategy to use.",
+    category="Auto-scaling options",
+    show_default=True,
+)
 # ******************************* MIN THROUGHPUT CONFIGURATION OPTIONS *******************************
 @click.option(
     "--min_throughput_rate",
@@ -696,6 +706,7 @@ def create_impl(**inference_kwargs: Any):
             "scaling_up_timeout_sec": inference_kwargs["scaling_up_timeout_sec"],
             "scaling_down_timeout_sec": inference_kwargs["scaling_down_timeout_sec"],
             "scale_to_zero_timeout_sec": inference_kwargs["scale_to_zero_timeout_sec"],
+            "autoscaling_strategy": inference_kwargs["autoscaling_strategy"],
         },
         "controller_cloud_config": (
             controller_config
